var splash = {

  init: function() {
    splash.resetValues(); // reset all prefs on major upgrades

    if (!nsPreferences.getBoolPref("splash.enabled")) {
      window.close();
    }

    var windowStyle = nsPreferences.copyUnicharPref("splash.windowStyle")
    document.getElementById("splashscreen").setAttribute("style", windowStyle);

    // If the imageURL is the default value and we are running Thunderbird, 
    // we need to change the default about image location
    var branchService = Components.classes["@mozilla.org/preferences-service;1"]
                        .getService(Components.interfaces.nsIPrefBranch);
    var splashURL;

    if (branchService.prefHasUserValue("splash.imageURL")) {
      splashURL = nsPreferences.copyUnicharPref("splash.imageURL");
    } else {
      splashURL = splash.getDefaultImage();
      nsPreferences.setUnicharPref("splash.imageURL", splashURL)
    }

    document.getElementById("splash.image").src = splashURL;

    var customStyle = ""
    var bgColor = nsPreferences.copyUnicharPref("splash.bgcolor");
    if (bgColor) {    
      customStyle = "background-color: " + bgColor + "; ";
    }

    document.getElementById("clientBox").setAttribute("style", customStyle)

    document.getElementById("splash.text").setAttribute("style", nsPreferences.copyUnicharPref("splash.textStyle"));

    if (nsPreferences.getBoolPref("splash.textHide")) {
      document.getElementById("splash.text").hidden = true; 
    } else {
      var textOverride = nsPreferences.copyUnicharPref("splash.textOverride");
      if (textOverride) {
        var appInfo = Components.classes['@mozilla.org/xre/app-info;1'].getService(Components.interfaces.nsIXULAppInfo);
        textOverride = textOverride.replace(/{appVersion}/ig, appInfo.version);
        textOverride = textOverride.replace(/{buildID}/ig, appInfo.appBuildID);

        document.getElementById("splash.text").value = textOverride; 
      }
      document.getElementById("splash.text").hidden = false; 
    }

    setTimeout(window.close, nsPreferences.getIntPref("splash.timeout"));

  },
  
  initSettings: function() {
    var splashURL

    var branchService = Components.classes["@mozilla.org/preferences-service;1"]
                        .getService(Components.interfaces.nsIPrefBranch);

    if (branchService.prefHasUserValue("splash.imageURL")) {
      splashURL = nsPreferences.copyUnicharPref("splash.imageURL");
    } else {
      splashURL = splash.getDefaultImage();
    }
    document.getElementById("splash.previewImage").src = splashURL;
  },

  playSound: function(isEnabled) {
    //soundURL = "chrome://extension/skin/file.wav";
    var soundURL = nsPreferences.copyUnicharPref("splash.soundURL");
    if (soundURL && isEnabled) {
      var gSound = Components.classes["@mozilla.org/sound;1"].
                 createInstance(Components.interfaces.nsISound);
      var ioService = Components.classes["@mozilla.org/network/io-service;1"].
                        getService(Components.interfaces.nsIIOService);
      var url = ioService.newURI(soundURL, null, null);
      
      gSound.play(url);
    }
  },
  
  getAppName: function() {
    var myBrandingPath = null;
    var myStringBundleService = Components.classes["@mozilla.org/intl/stringbundle;1"]
                        .getService(Components.interfaces.nsIStringBundleService);
    
    if (typeof Components.interfaces.nsIXULAppInfo == "undefined") {
      myBrandingPath = "chrome://global/locale/brand.properties"
    } else { 
      myBrandingPath = "chrome://branding/locale/brand.properties"
    }
    
    var myBrandStrings = myStringBundleService.createBundle(myBrandingPath);

    return myBrandStrings.GetStringFromName("brandShortName");
  },

  openURL: function(myLink) {
    var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
                       .getService(Components.interfaces.nsIWindowMediator);

    var browserWindow = wm.getMostRecentWindow("navigator:browser");

    if (browserWindow) {
      var browserWindow = browserWindow.getBrowser();
      var newTab = browserWindow.addTab(myLink, null, null);
      browserWindow.selectedTab = newTab;
    } else {
      var ioService = Components.classes["@mozilla.org/network/io-service;1"]
                                .getService(Components.interfaces.nsIIOService);
      var uri = ioService.newURI(myLink, null, null);
      var extProtocolSvc = Components.classes["@mozilla.org/uriloader/external-protocol-service;1"]
                                     .getService(Components.interfaces.nsIExternalProtocolService);
  
      extProtocolSvc.loadUrl(uri);
    }
  },
  
  previewSplashScreen: function() {
    var xWidth = nsPreferences.getIntPref("splash.windowWidth");

    var xHeight = nsPreferences.getIntPref("splash.windowHeight");

    if (!nsPreferences.getBoolPref("splash.textHide")) {
      xHeight += 30;
    }

    var windowParams = ",width=" + xWidth + ",height=" + xHeight;

    splash.playSound(nsPreferences.getBoolPref("splash.soundEnabled"));
    openDialog("chrome://splash/content/splash.xul", "SplashScreen",
              "chrome,centerscreen,alwaysRaised,titlebar=no,modal=no,dependent" + windowParams);
  },

  resetToDefault: function() {
    var prefService = Components.classes["@mozilla.org/preferences-service;1"].
      getService(Components.interfaces.nsIPrefService);

    var nsIPrefBranchObj = prefService.getBranch("splash.");
    var prefCount = {value:0}; 
    var prefArray = nsIPrefBranchObj.getChildList("" , prefCount); 

    var branchService = Components.classes["@mozilla.org/preferences-service;1"]
                                   .getService(Components.interfaces.nsIPrefBranch);

    for (var i = 0; i < prefArray.length; ++i) {
      if (branchService.prefHasUserValue("splash." + prefArray[i])) {
         branchService.clearUserPref("splash." + prefArray[i]);
      }
    } 
  },
  
  getSoundFile: function() {
    var mStrings = document.getElementById("splashStrings");
    
    const nsIFilePicker = Components.interfaces.nsIFilePicker;
  
    var fp = Components.classes["@mozilla.org/filepicker;1"].createInstance(nsIFilePicker);
    fp.init(window, mStrings.getString("splash_select_sound"), nsIFilePicker.modeOpen);
    fp.appendFilter(mStrings.getString("splash_sound_filter_label"), "*.wav");
  
    var ret = fp.show();
    
    if(ret == nsIFilePicker.returnOK) {
     document.getElementById("pref_splash.soundURL").value = fp.fileURL.spec;
  //   document.getElementById("pref_splash.soundEnabled").checked = true;
    }
  },
  
  getImageFile: function() {
    var mStrings = document.getElementById("splashStrings");
    
    const nsIFilePicker = Components.interfaces.nsIFilePicker;
  
    var fp = Components.classes["@mozilla.org/filepicker;1"].createInstance(nsIFilePicker);
    fp.init(window, mStrings.getString("splash_select_image"), nsIFilePicker.modeOpen);
    fp.appendFilters(nsIFilePicker.filterImages);
  
    var ret = fp.show();
    
    if(ret == nsIFilePicker.returnOK) {
     document.getElementById("pref_splash.imageURL").value = fp.fileURL.spec;
     document.getElementById("splash.previewImage").src = fp.fileURL.spec;
    }
  },
  
  getDefaultImage: function() {
    var splashDefaultURL

    switch (splash.getAppName()) {
      case "Thunderbird":
        splashDefaultURL = "chrome://branding/content/about-thunderbird.png";
        break;
      case "Calendar":
      case "Sunbird":
        splashDefaultURL = "chrome://calendar/content/about-sunbird.png";
        break;
      default:
        splashDefaultURL = "chrome://branding/content/about.png";
    }
    return splashDefaultURL;
  },
  
  setDefaultImage: function() {
    var defaultImage = splash.getDefaultImage();
    nsPreferences.setUnicharPref('splash.imageURL', defaultImage)
    document.getElementById("splash.previewImage").src = defaultImage;
  },
  
  getDimensions: function() {
    var previewImage = document.getElementById("splash.previewImage");
    
    document.getElementById("splash.windowWidth").value = previewImage.boxObject.width;
    document.getElementById("splash.windowHeight").value =previewImage.boxObject.height;
    
    nsPreferences.setIntPref("splash.windowWidth", previewImage.boxObject.width);
    nsPreferences.setIntPref("splash.windowHeight", previewImage.boxObject.height);
  },

  resetValues: function() {
    var myResetVersion = nsPreferences.copyUnicharPref("splash.resetVersion");
    var thisResetVersion = "0.9.2";
    
    if (myResetVersion != thisResetVersion) {
      var prefService = Components.classes["@mozilla.org/preferences-service;1"]
                          .getService(Components.interfaces.nsIPrefService);
      var nsIPrefBranchObj = prefService.getBranch("splash.");
      var prefCount = {value:0}; 
      var prefArray = nsIPrefBranchObj.getChildList("" , prefCount); 
  
      var branchService = nsPreferences.mPrefService;
  
      for (var i = 0; i < prefArray.length; ++i) {
        if (branchService.prefHasUserValue("splash." + prefArray[i])) {
           branchService.clearUserPref("splash." + prefArray[i]);
        }
      } 

      nsPreferences.setUnicharPref("splash.resetVersion", thisResetVersion);
    }
  }
  
}
/*
function logString(aLogString) {
  var mConsoleService = Components.classes["@mozilla.org/consoleservice;1"]
         .getService(Components.interfaces.nsIConsoleService)

	if(mConsoleService) {
  	mConsoleService.logStringMessage("Splash: " + aLogString + "\n");
  }
}*/